# CHANGELOG

## 1.1.0 (2019-09-27)

* JSON login option to support [Sourcing Credentials with an External Process](https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sourcing-external.html) with awscli (thanks [@ajkerrigan](https://github.com/ajkerrigan))

## 1.0.0 (2019-09-16)

* Initial release
* Console Sign-In
* Properly detect authentication failures

## 0.0.1-alpha.3 (2019-08-26)

* Initial pre-release
